@@ -2,6 +2,7 @@ package hugogenerator
 
 import (
 	"fmt"
+	"github.com/ashishb/wp2hugo/src/wp2hugo/internal/hugogenerator/hugopage"
 	"github.com/ashishb/wp2hugo/src/wp2hugo/internal/wpparser"
 	"github.com/rs/zerolog/log"
 )
@@ -10,15 +11,18 @@ type WordPressImageURLProvider struct {
 	info wpparser.WebsiteInfo
 }
 
-func (w WordPressImageURLProvider) GetImageURL(imageID string) (*string, error) {
+func (w WordPressImageURLProvider) GetImageInfo(imageID string) (*hugopage.ImageInfo, error) {
 	log.Debug().Str("imageID", imageID).Msg("GetImageURL")
-	for _, attachment := range w.info.Attachments {
+	for _, attachment := range w.info.Attachments() {
 		if attachment.PostID == imageID {
 			attachmentURL := attachment.GetAttachmentURL()
 			log.Info().
 				Str("imageID", imageID).
 				Str("Link", *attachmentURL).Msg("Image URL found")
-			return attachmentURL, nil
+			return &hugopage.ImageInfo{
+				ImageURL: *attachmentURL,
+				Title:    attachment.Title,
+			}, nil
 		}
 	}
 	log.Error().Str("imageID", imageID).Msg("Image URL not found")
